@@ -755,7 +755,7 @@ class NullProvider(
         '''Create a new {@link https://www.terraform.io/docs/providers/null null} Resource.
 
         :param scope: The scope in which to define this construct.
-        :param id: The scoped construct ID.
+        :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/null#alias NullProvider#alias}
         '''
         config = cdktf_cdktf_provider_null.NullProviderConfig(alias=alias)
@@ -772,7 +772,7 @@ class NullProvider(
 
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="tfResourceType")
-    def tf_resource_type(cls) -> builtins.str:
+    def TF_RESOURCE_TYPE(cls) -> builtins.str:
         return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))
 
     @builtins.property # type: ignore[misc]
